﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Caching.Memory;
using Health.Api.Infrastructure;
//using Health.Api.Infrastructure.Models;
using Health.Api.Infrastructure.Modules;

using Health.Api.Infrastructure.Queries;
using Health.Api.Infrastructure.Request;
using Health.Infra;
namespace Health.Api.Controllers
{
	[Authorize]
	[Route("api/resource")]
	[ApiController]
	public class ResourceController : ControllerBase
	{
		private readonly IMemoryCache _cache;
		private readonly ResourceQueries resourceQueries;

		public ResourceController(
			IMemoryCache cache,
			ResourceQueries resourceQueries)
		{
			this._cache = cache;
			this.resourceQueries = resourceQueries;
		}
		/// <summary>
		/// 查询当月项目
		/// </summary>
		/// <param name="source">  </param>
		/// <returns></returns>
		[HttpGet("ItemQuery")]
		[AllowAnonymous]
		public IEnumerable<dynamic> ItemQuery( )
		{
			var ItemQueryList = resourceQueries.ItemQuery( );
			return ItemQueryList;
		}
		/// <summary>
		/// 取消正在查询项目
		/// </summary>
		/// <param name="id">id </param>
		/// <returns></returns>
		[HttpPost("CancelProject")]
		[AllowAnonymous]
		public bool CancelProject(int id)
		{
			bool ItemQueryList = resourceQueries.CancelProject(id);

			return ItemQueryList;
		}
		/// <summary>
		/// 查询项目报告
		/// </summary>
		/// <param name="source">药品 疾病 同查 全部 </param>
		/// <returns></returns>
		[HttpPost("ProjectReport")]
		[AllowAnonymous]
		public (IEnumerable<dynamic> yearDistribution, IEnumerable<dynamic> regionalDistribution ,string queryCriteria,string title) ProjectReport([FromBody] SYS_Cs sYS_Cs)
		{
			return   resourceQueries.ProjectReport(sYS_Cs.id, sYS_Cs.MEDIC_AREA, sYS_Cs.item_name, sYS_Cs.GENERIC_NAME, sYS_Cs.PROJECT_NAME, sYS_Cs.icd, sYS_Cs.DISEASE_NAME); 
		}
		/// <summary>
		/// 查询流水库表
		/// </summary>
		/// <returns></returns>
		[HttpPost("QueryFlowDatabase")]
		[AllowAnonymous]
		public IEnumerable<dynamic> QueryFlowDatabase()
		{
			return resourceQueries.QueryFlowDatabase();
		}
		/// <summary>
		/// 查询药品产地
		/// </summary>
		/// <returns></returns>
		[HttpPost("ShowMEDIC_AREA")]
		[AllowAnonymous]
		public (IEnumerable<dynamic>, IEnumerable<dynamic>) ShowMEDIC_AREA(int id, int paseIndex)
		{
			return resourceQueries.ShowMEDIC_AREA(id, paseIndex);
		}
		/// <summary>
		/// 查询名称产地
		/// </summary>
		/// <returns></returns>
	    [HttpPost("ShowITEM_NAME")]
		[AllowAnonymous]
		public (IEnumerable<dynamic>, IEnumerable<dynamic>) ShowITEM_NAME(int id, int paseIndex)
		{
			return resourceQueries.ShowITEM_NAME(id, paseIndex);
		}
		/// <summary>
		/// 建立流水库表
		/// </summary>
		/// <returns></returns>
		[HttpPost("EstablishFlowDatabaseTable")]
		[AllowAnonymous]
		public bool EstablishFlowDatabaseTable([FromBody] SYS_EstablishFlowDatabaseTable sYS_EstablishFlows)
		{
			return resourceQueries.EstablishFlowDatabaseTable(sYS_EstablishFlows.tableName, sYS_EstablishFlows.sql, sYS_EstablishFlows.id, sYS_EstablishFlows.remarks); ;

		}
		/// <summary>
		/// 建立流水库
		/// </summary>
		/// <returns></returns>
		 [HttpPost("CreateAFlow_Library")]
		[AllowAnonymous]
		public bool CreateAFlow_Library(string DatabaseName,int indexs)
		{
			return resourceQueries.CreateAFlow_Library(DatabaseName,indexs);
	    }

		/// <summary>
		/// 查询日志
		/// </summary>
		/// <returns></returns>
		[HttpPost("ShowLog")]
		[AllowAnonymous]
		public (IEnumerable<dynamic>, IEnumerable<dynamic>) ShowLog(int indexs, int paseIndex, string type)
		{
			return resourceQueries.ShowLog(indexs,paseIndex,type);
		}


		/// <summary>
		/// 拉取流水库数据
		/// </summary>
		/// <returns></returns> 
		[HttpPost("PullData")]
		[AllowAnonymous]
		public  void PullData(int indexs,string DatabaseName,string tableName)
		  {
			resourceQueries.PullData(indexs, DatabaseName, tableName, "PUB_PATIENT");
			//拉取登记
			resourceQueries.PullData(indexs, DatabaseName, tableName, "OUT_REG_INFO");
			resourceQueries.PullData(indexs, DatabaseName, tableName, "INPAT_REG_INFO");
			//拉取诊断
			resourceQueries.PullData(indexs, DatabaseName, tableName, "OUT_DIAG");
			resourceQueries.PullData(indexs, DatabaseName, tableName, "INPAT_DIAG");
			
			resourceQueries.PullData(indexs, DatabaseName, tableName, "OPS_INFO");
			resourceQueries.PullData(indexs, DatabaseName, tableName, "ASSAY_REPORT");
			resourceQueries.PullData(indexs, DatabaseName, tableName, "EXEC_REPORT");
			resourceQueries.PullData1(indexs, DatabaseName, tableName, "OUT_PRES");
			resourceQueries.PullData1(indexs, DatabaseName, tableName, "OUT_FEE");
			resourceQueries.PullData1(indexs, DatabaseName, tableName, "INPAT_ORDER");
			resourceQueries.PullData1(indexs, DatabaseName, tableName, "INPAT_FEE");
		}

		/// <summary>
		/// 药品疾病查询平台
		/// </summary>
		/// <returns></returns> 
		[HttpPost("Inquire")]
		[AllowAnonymous]    
		public void Inquire(SYS_QueryConditions sYS_Query)
		{
			 if(sYS_Query.icd.Length>1||sYS_Query.diseaseName.Length > 1 )
            {
				sYS_Query.type = 1;  //疾病查询 
				resourceQueries.DiagInquire(sYS_Query.icd, sYS_Query.diseaseName);
			} 
            else
            {
				throw new DomainException($@"材料费只支持单独查询！");
			}
		}
	}
}
